@@ -1,10 +1,10 @@
 import os
-from dorothy_sdk.session import Session
+import tempfile
 from requests import Session
 from PIL import Image as PILImage
 from io import BytesIO
 
-CACHE_LOCATION = "/tmp/image_service/images/"
+CACHE_LOCATION = os.path.join(tempfile.gettempdir(), "image_service", "images")
 CACHE_ENABLED = False
 
 
